﻿using SummaryRowsSample;
using Syncfusion.Data;
using Syncfusion.SfDataGrid;
using System;
using System.Collections.Generic;
using System.Text;
using UIKit;
using System.Linq;

namespace SummaryDemo
{
    
    public class MyViewController : UIViewController
    {
        SfDataGrid datagrid;
        ViewModel viewModel;
        public MyViewController()
        {
            datagrid = new SfDataGrid();
            viewModel = new ViewModel();
            datagrid.AutoGenerateColumns = true;
            datagrid.ColumnSizer = ColumnSizer.Star;
			datagrid.ItemsSource = viewModel.OrdersInfo;
			datagrid.GroupColumnDescriptions.Add(new GroupColumnDescription() { ColumnName = "Description" });

            GridSummaryRow summaryRow = new GridSummaryRow();
			summaryRow.ShowSummaryInRow = false;

			GridSummaryColumn summary = new GridSummaryColumn();
			summary.Name = "Paid";
			summary.MappingName = "Paid";
			summary.Format = "{Sum:c}";
			summary.SummaryType = SummaryType.DoubleAggregate;

			GridSummaryColumn summary1 = new GridSummaryColumn();
			summary1.Name = "Incurred";
			summary1.MappingName = "Incurred";
			summary1.Format = "{Sum:c}";
			summary1.SummaryType = SummaryType.DoubleAggregate;

			GridSummaryColumn summary2 = new GridSummaryColumn();
			summary2.Name = "Reserves";
			summary2.MappingName = "Reserves";
			summary2.Format = "{Sum:c}";
			summary2.SummaryType = SummaryType.DoubleAggregate;

			summaryRow.SummaryColumns.Add(new GridSummaryColumn
			{
				Name = "Description",
				CustomAggregate = new CustomAggregate(),
				MappingName = "Description",
				Format = "{totalSum}",
				SummaryType = Syncfusion.Data.SummaryType.Custom
			});

			GridSummaryColumn summary4 = new GridSummaryColumn();
			summary4.Name = "Code";
			summary4.MappingName = "Code";
			summary4.Format = "{Count}"+"Count";
			summary4.SummaryType = SummaryType.CountAggregate;

			summaryRow.SummaryColumns.Add(summary);
			summaryRow.SummaryColumns.Add(summary1);
			summaryRow.SummaryColumns.Add(summary2);
			summaryRow.SummaryColumns.Add(summary4);

            datagrid.CaptionSummaryRow = summaryRow;

			View.AddSubviews(datagrid);


        }
        public override void ViewDidLayoutSubviews()
        {
            datagrid.Frame = new CoreGraphics.CGRect(0, 0, View.Frame.Width, View.Frame.Height );
            base.ViewDidLayoutSubviews();
        }
    }
	public class CustomAggregate : ISummaryAggregate
	{
		public CustomAggregate()
		{ 
			
		}
		public double totalSum { get; set; }
		public Action<System.Collections.IEnumerable, string, System.ComponentModel.PropertyDescriptor> CalculateAggregateFunc()
		{
			return (items, property, pd) =>
			 {
				 var enumerableItems = items as IEnumerable<OrderInfo>;
				 if (pd.Name == "totalSum")
				 {
					this.totalSum = enumerableItems.totalSum<OrderInfo>(q=>q.Incurred+q.Paid+q.Reserves);
				 }
			 };
		}
	}
	public static class LinqExtensions
	{
		public static double totalSum<T>(this IEnumerable<T> values, Func<T, double?> selector)
		{
			double sum = 0;
			var count = values.Count();
			foreach (var v in values )
			{
				OrderInfo a = v as OrderInfo;
				 sum =  sum +a.Paid+a.Incurred+a.Reserves;
			}
	 			return sum;
		}
	}
}
